﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace LevelEditor
{
    public partial class Map : Form, IMapSettings
    {
        Image mapImage, tileSheet;

        public Image TileSheet
        {
            get { return tileSheet; }
            set
            {
                tileSheet = value;
                tileSheetPictureBox.MapParent = this;
                tileSheetPictureBox.Image = tileSheet;
                tileSheetPictureBox.Width = mapImage.Width;
                tileSheetPictureBox.Height = mapImage.Height;
                tabControl.SelectedIndex = 1;
            }
        }

        public int SelectedTileIndex
        {
            get { return tileSheetPictureBox.SelectedTileIndex; }
        }

        public Rectangle SelectedTileRectangle
        {
            get { return tileSheetPictureBox.SelectedTileRectangle; }
        }

        public Map(IMapSettings source)
        {
            LevelEditor.CopySettings(source, this);
            InitializeComponent();

            mapImage = new Bitmap(MapWidth * TileWidth, MapHeight * TileHeight);
            Graphics g = Graphics.FromImage(mapImage);
            g.Clear(Color.Black);
            mapPictureBox.MapParent = this;
            mapPictureBox.Image = mapImage;
            mapPictureBox.Width = mapImage.Width;
            mapPictureBox.Height = mapImage.Height;
            mapPictureBox.Click += new EventHandler(pictureBoxMap_Click);
            mapPictureBox.MouseMove += new MouseEventHandler(pictureBoxMap_MouseMove);
        }

        private void DrawTile()
        {
            Graphics g = Graphics.FromImage(mapImage);

            if (TileSheet != null && SelectedTileIndex != -1)
            {
                Rectangle dest = new Rectangle(mapPictureBox.TilePixelPosition.X, mapPictureBox.TilePixelPosition.Y,
                    TileWidth, TileHeight);
                g.DrawImage(TileSheet, dest, tileSheetPictureBox.SelectedTileRectangle, GraphicsUnit.Pixel);
            }
        }

        #region mapPictureBox Events

        void pictureBoxMap_MouseMove(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Left)
            {
                DrawTile();
            }
        }

        void pictureBoxMap_Click(object sender, EventArgs e)
        {
            DrawTile();
        }

        #endregion

        #region IMapSettings Members

        public int MapWidth
        {
            get;
            set;
        }

        public int MapHeight
        {
            get;
            set;
        }

        public int TileWidth
        {
            get;
            set;
        }

        public int TileHeight
        {
            get;
            set;
        }

        #endregion
    }
}
