﻿using System;
using System.ComponentModel;
using System.Data;
using System.Windows.Forms;
using System.Drawing;
using LevelEditor;
using System.Drawing.Imaging;

namespace LevelEditorControls
{
    class MapPictureBox : PictureBox
    {
        int mouseX, mouseY;
        bool drawTile;

        public Map MapParent
        {
            get;
            set;
        }

        public Point TilePosition
        {
            get
            {
                return new Point(mouseX / MapParent.TileWidth, mouseY / MapParent.TileHeight);
            }
        }

        public Point TilePixelPosition
        {
            get
            {
                int drawX = mouseX - (mouseX % MapParent.TileWidth);
                int drawY = mouseY - (mouseY % MapParent.TileHeight);
                return new Point(drawX, drawY);
            }
        }

        public MapPictureBox()
        {
        }

        protected override void OnPaint(PaintEventArgs pe)
        {
            base.OnPaint(pe);
            
            if (drawTile && MapParent != null && MapParent.SelectedTileIndex != -1)
            {
                Rectangle dest = new Rectangle(TilePixelPosition.X, TilePixelPosition.Y,
                    MapParent.TileWidth, MapParent.TileHeight);
                Rectangle src = MapParent.SelectedTileRectangle;

                ColorMatrix cm = new ColorMatrix();
                cm.Matrix00 = cm.Matrix11 = cm.Matrix22 = cm.Matrix44 = 1;
                cm.Matrix33 = 0.5f;
                ImageAttributes ia = new ImageAttributes();
                ia.SetColorMatrix(cm);
                pe.Graphics.DrawImage(MapParent.TileSheet, dest, src.X, src.Y, src.Width, src.Height, GraphicsUnit.Pixel, ia);
            }
        }

        protected override void OnMouseMove(MouseEventArgs e)
        {
            mouseX = e.X;
            mouseY = e.Y;
            base.OnMouseMove(e);
            this.Invalidate();
        }

        protected override void OnMouseEnter(EventArgs e)
        {
            base.OnMouseEnter(e);
            drawTile = true;
            this.Invalidate();
        }

        protected override void OnMouseLeave(EventArgs e)
        {
            base.OnMouseLeave(e);
            drawTile = false;
            this.Invalidate();
        }
    }
}